#!/bin/bash

COMPAT_MAJOR=("24")
COMPAT_MINOR=("2.1")

COMPAT_PROFILES=("astro" "elroy" "orbitty" "rosie" "rudi" )

COMPAT_JETSON=("TX1")

CTI_L4T_VER="V009"

chkroot(){

    if [ $EUID -ne 0 ]
    then
        echo "Please run as sudo or root"
        exit 1
    fi
}

print_versions(){

    echo "Supportted Version Information"
    echo "  CTI-L4T Board Support Package Version:" $CTI_L4T_VER

    echo "  Supported CTI Products (profiles): "   
    for i in ${COMPAT_PROFILES[@]}; do 
        echo "    " $i
    done

    echo "  Supported Linux for Tegra Release Versions: "
    for j in ${COMPAT_MINOR[@]}; do 
        echo "    " $COMPAT_MAJOR"."$j
    done

    echo "  Supported Nvidia Jetson Module Hardware: "
    for k in ${COMPAT_JETSON[@]}; do 
        echo "    " $k
    done

}

usage(){
	echo -e "  Usage: ./install.sh <full|minimal> [profile] "
	echo -e "  Choose either full or minimal install method"
    echo -e "  minimal installs the Device Trees, CTI's L4T utility and all needed config files"
    echo -e "  full installs all of minimal as well as CTI's optimized kernel"
	echo -e "  profile is the profile (product name) to set initially"
    echo -e "  Note that the full install may be needed to take advantage of all features"
    echo -e "  Before installing this BSP, please read the included readme.txt"
    echo -e "  The profile can be changed at anytime using the cti-l4t-util"
    echo -e "  Please ensure your software and hardware match the verions below\n"

    print_versions
	exit
}

install_dtbs(){

    chkroot
    cp -vr kernel/dtb/* /boot/

}

install_etc(){

    chkroot
    cp -r etc/ /
    cp readme.txt /etc/cti/

}

install_bin(){

    chkroot
    cp -vr bin/* /usr/bin

}

install_kernel(){

    chkroot

    cp -v kernel/Image kernel/zImage /boot
    cp kernel/kernel_supplements.tbz2 /
    tar -xjf /kernel_supplements.tbz2 -C /
    rm -rf /kernel_supplements.tbz2

}

chk_l4t_version(){

    if [ ! -f /etc/nv_tegra_release ]; then
        echo "/etc/nv_tegra_release not found"
        eval $1="notfound"
        return
    fi

    major=$( sed -ne '/REV/p' /etc/nv_tegra_release | cut -d " " -f 2 | tr -d "R") 
    
    minor=$( sed -ne '/REV/p' /etc/nv_tegra_release | cut -d " " -f 5 | tr -d "," ) 

    #Check Major verison against the comaptible versions
    for i in ${COMPAT_MAJOR[@]}; do
        if [ "$i" == "$major" ]; then
            #check them inor versions again the compatible versions             
            for j in ${COMPAT_MINOR[@]}; do
                if [ "$j" == "$minor" ]; then
                    
                eval $1="compatible"
                return
                    
                fi
            
            done

        fi 

    done
    #if it makes it here it isnt compatible
   eval $1="incompatible"

}

if [ "$#" -lt 2 ];then

    usage
    exit
fi

chk_l4t_version ret

if [ "$ret" != "compatible" ]; then
   echo "The installed L4T version is incompatible with this version of the CTI-L4T Board Support Package"
  exit
fi
#extract resources
tar -pxzf resources.tgz

COMMAND=$1
PROFILE=$2
case $COMMAND in
    full)
        install_dtbs
        install_etc
        install_kernel
        install_bin
        cti-l4t-util profile -c $PROFILE
    ;;

    minimal)
        install_etc
        install_dtbs
        install_bin
        cti-l4t-util profile -c $PROFILE
    ;;

    *)
        usage
        exit
    ;;

esac

